@@ -60,8 +60,9 @@ class Processor(object):
         self.application.ioloop.add_timeout(self.application.interval, self.application.next)
 
     def wait(self):
-        return_code = self.process.returncode
-        print "wait", return_code
+        print "wait"
+        return_code = self.process.wait(1)
+        print "wait done", return_code
         if return_code is None:
             self.application.ioloop.add_timeout(self.application.interval, self.wait)
         elif return_code == 0:
